# trad-setlist-helper

Use data from The Session to generate incipts for a list of tune sets.

---

Would be nice to add:

- [ ] fuzzy name matching
- [ ] fuzzy key/mode matching (e.g. same key sig, maybe even min and dor matching)
- [ ] default to Norbeck or such for the transcription if available
